# Torch Book

[![PyPI](https://img.shields.io/pypi/v/torch-book.svg)](https://pypi.org/project/torch-book/) [![GitHub issues](https://img.shields.io/github/issues/xinetzone/torch-book)](https://github.com/xinetzone/torch-book/issues) [![GitHub forks](https://img.shields.io/github/forks/xinetzone/torch-book)](https://github.com/xinetzone/torch-book/network) [![GitHub stars](https://img.shields.io/github/stars/xinetzone/torch-book)](https://github.com/xinetzone/torch-book/stargazers) [![GitHub license](https://img.shields.io/github/license/xinetzone/torch-book)](https://github.com/xinetzone/torch-book/blob/main/LICENSE) ![repo size](https://img.shields.io/github/repo-size/xinetzone/torch-book.svg) [![contributors](https://img.shields.io/github/contributors/xinetzone/torch-book.svg)](https://github.com/xinetzone/torch-book/graphs/contributors) [![watcher](https://img.shields.io/github/watchers/xinetzone/torch-book.svg)](https://github.com/xinetzone/torch-book/watchers) [![watcher](https://img.shields.io/github/watchers/xinetzone/pytorch-book.svg)](https://github.com/xinetzone/pytorch-book/watchers) [![Documentation Status](https://readthedocs.org/projects/torch-book/badge/?version=latest)](https://torch-book.readthedocs.io/zh/latest/?badge=latest) [![Downloads](https://pepy.tech/badge/torch-book/week)](https://pepy.tech/project/torch-book)  [![Downloads](https://pepy.tech/badge/torch-book)](https://pepy.tech/project/torch-book)

## 支持 PyPI

需要安装 `demo-book` 包：

```shell
pip install demo-book
```
